@@ -18,5 +18,6 @@
 #'  \cite{Clark et al. (2021), "The abuse of popular performance metrics in hydrologic modeling", Water Resources Research, <doi:10.1029/2020WR029001>.}
 #'
 #' @import dplyr ggplot2 lubridate stringr ncdf4
-NULL
+#' @keywords package
+"_PACKAGE"
 
